@@ -145,7 +145,9 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         match infer_schema_from_stats(&args, &input_filename) {
             Ok(map) => map,
             Err(e) => {
-                return fail_clierror!("Failed to infer schema via stats and frequency: {e}");
+                return fail_clierror!(
+                    "Failed to infer schema via stats and frequency from {input_filename}: {e}"
+                );
             }
         };
 
@@ -237,24 +239,30 @@ pub fn infer_schema_from_stats(args: &Args, input_filename: &str) -> CliResult<M
     let mut field_map: Map<String, Value> = Map::with_capacity(10);
     let mut type_list: Vec<Value> = Vec::with_capacity(4);
     let mut enum_list: Vec<Value> = Vec::with_capacity(args.flag_enum_threshold);
+    let mut header_byte_slice;
+    let mut header_string;
+    let mut stats_record;
+    let mut col_type;
+    let mut col_null_count;
 
     // generate definition for each CSV column/field and add to properties_map
     for i in 0..csv_fields.len() {
-        let header_byte_slice = csv_fields.get(i).unwrap();
+        header_byte_slice = csv_fields.get(i).unwrap();
+
         // convert csv header to string
-        let header_string = convert_to_string(header_byte_slice)?;
+        header_string = convert_to_string(header_byte_slice)?;
 
         // grab stats record for current column
-        let stats_record = csv_stats.get(i).unwrap().clone().to_record(4);
+        stats_record = csv_stats.get(i).unwrap().clone().to_record(4);
 
         if log::log_enabled!(log::Level::Debug) {
             debug!("stats[{header_string}]: {stats_record:?}");
         }
 
         // get Type from stats record
-        let col_type = stats_record.get(stats_col_index_map["type"]).unwrap();
+        col_type = stats_record.get(stats_col_index_map["type"]).unwrap();
         // get NullCount
-        let col_null_count = if let Some(s) = stats_record.get(stats_col_index_map["nullcount"]) {
+        col_null_count = if let Some(s) = stats_record.get(stats_col_index_map["nullcount"]) {
             s.parse::<usize>().unwrap_or(0_usize)
         } else {
             0_usize
@@ -398,7 +406,7 @@ pub fn infer_schema_from_stats(args: &Args, input_filename: &str) -> CliResult<M
     Ok(properties_map)
 }
 
-/// get stats records from `cmd::stats`
+/// get stats records from stats.bin file, or if its invalid, by running the stats command
 /// returns tuple (`csv_fields`, `csv_stats`, `stats_col_index_map`)
 fn get_stats_records(args: &Args) -> CliResult<(ByteRecord, Vec<Stats>, AHashMap<String, usize>)> {
     let stats_args = crate::cmd::stats::Args {
@@ -422,30 +430,118 @@ fn get_stats_records(args: &Args) -> CliResult<(ByteRecord, Vec<Stats>, AHashMap
         flag_no_headers:      args.flag_no_headers,
         flag_delimiter:       args.flag_delimiter,
         flag_no_memcheck:     args.flag_no_memcheck,
+        flag_stats_binout:    None,
     };
 
-    let (csv_fields, csv_stats) = match stats_args.rconfig().indexed() {
-        Ok(o) => {
-            if let Some(idx) = o {
-                winfo!("index found... triggering parallel stats");
-                let idx_count = idx.count();
-                stats_args.parallel_stats(&stats_args.flag_dates_whitelist, idx_count)
-            } else {
-                winfo!(
-                    "no index, triggering sequential stats. Consider indexing your data if schema \
-                     inferencing is slow. "
-                );
-                stats_args.sequential_stats(&stats_args.flag_dates_whitelist)
+    let stats_binary_encoded_path = args.arg_input.clone().unwrap();
+    let stats_binary_encoded_path = Path::new(&stats_binary_encoded_path)
+        .to_path_buf()
+        .with_extension("stats.csv.bin");
+
+    let stats_bin_current = if stats_binary_encoded_path.exists() {
+        let stats_bin_metadata = std::fs::metadata(&stats_binary_encoded_path)?;
+
+        let input_metadata = std::fs::metadata(&args.arg_input.clone().unwrap())?;
+
+        if stats_bin_metadata.modified()? > input_metadata.modified()? {
+            info!("Valid stats.csv.bin file found!");
+            true
+        } else {
+            info!("stats.csv.bin file is older than input file. Regenerating stats.bin file.");
+            false
+        }
+    } else {
+        info!("stats.csv.bin file does not exist: {stats_binary_encoded_path:?}");
+        false
+    };
+
+    let mut stats_bin_loaded = false;
+
+    // if stats.bin file exists and is current, use it
+    let mut csv_stats: Vec<Stats> = Vec::with_capacity(100_000_000);
+
+    if stats_bin_current {
+        let mut bin_file = File::open(stats_binary_encoded_path)?;
+        match bincode::deserialize_from(&mut bin_file) {
+            Ok(stats) => {
+                csv_stats = stats;
+                stats_bin_loaded = true;
+            }
+            Err(e) => {
+                wwarn!("Error reading stats.csv.bin file: {e:?}. Regenerating stats.bin file.");
             }
         }
-        Err(e) => {
-            wwarn!("error determining if indexed, triggering sequential stats: {e}");
-            stats_args.sequential_stats(&stats_args.flag_dates_whitelist)
+    }
+
+    if !stats_bin_loaded {
+        // otherwise, run stats command to generate stats.csv.bin file
+        let tempfile = tempfile::Builder::new()
+            .suffix(".stats.csv")
+            .tempfile()
+            .unwrap();
+        let tempfile_path = tempfile.path().to_str().unwrap().to_string();
+
+        let tempfile_statsbin = tempfile::Builder::new()
+            .suffix(".stats.csv.bin")
+            .tempfile()
+            .unwrap();
+        let tempfile_statsbin_path = tempfile_statsbin.path().to_str().unwrap().to_string();
+
+        let mut stats_args_str = format!(
+            "stats {input} --infer-dates --dates-whitelist {dates_whitelist} --round 4 \
+             --cardinality --output {output} --stats-binout {binout} --force",
+            input = {
+                if let Some(arg_input) = stats_args.arg_input.clone() {
+                    arg_input
+                } else {
+                    "-".to_string()
+                }
+            },
+            dates_whitelist = stats_args.flag_dates_whitelist,
+            output = tempfile_path,
+            binout = tempfile_statsbin_path,
+        );
+        if args.flag_prefer_dmy {
+            stats_args_str = format!("{stats_args_str} --prefer-dmy");
         }
-    }?;
+        if args.flag_no_headers {
+            stats_args_str = format!("{stats_args_str} --no-headers");
+        }
+        if let Some(delimiter) = args.flag_delimiter {
+            let delim = delimiter.as_byte() as char;
+            stats_args_str = format!("{stats_args_str} --delimiter {delim}");
+        }
+        if args.flag_no_memcheck {
+            stats_args_str = format!("{stats_args_str} --no-memcheck");
+        }
+        if let Some(mut jobs) = stats_args.flag_jobs {
+            if jobs > 2 {
+                jobs -= 1; // leave one core for the main thread
+            }
+            stats_args_str = format!("{stats_args_str} --jobs {jobs}");
+        }
+
+        let stats_args_vec: Vec<&str> = stats_args_str.split_whitespace().collect();
+
+        let qsv_bin = std::env::current_exe().unwrap();
+        let mut stats_cmd = std::process::Command::new(qsv_bin);
+        stats_cmd.args(stats_args_vec);
+        let _stats_output = stats_cmd.output()?;
+
+        let mut bin_file = File::open(tempfile_statsbin_path).unwrap();
+
+        #[allow(unused_assignments)]
+        let mut decoded_stats: Vec<Stats> = Vec::with_capacity(100_000_000); // minimize allocs
+        decoded_stats = bincode::deserialize_from(&mut bin_file).unwrap();
+        csv_stats = decoded_stats;
+    };
+
+    // get the headers from the input file
+    let mut rdr = csv::Reader::from_path(args.arg_input.clone().unwrap()).unwrap();
+    let csv_fields = rdr.byte_headers()?.clone();
+    drop(rdr);
 
     let stats_columns = stats_args.stat_headers();
-    debug!("stats columns: {stats_columns:?}");
 
     let mut stats_col_index_map = AHashMap::new();
 
@@ -497,7 +593,7 @@ fn build_low_cardinality_column_selector_arg(
     column_select_arg
 }
 
-/// get frequency tables from `cmd::stats`
+/// get frequency tables from `cmd::frequency`
 /// returns map of unique values keyed by header
 fn get_unique_values(
     args: &Args,
@@ -523,7 +619,6 @@ fn get_unique_values(
     }?;
 
     let unique_values_map = construct_map_of_unique_values(&headers, &ftables)?;
-
     Ok(unique_values_map)
 }
 
@@ -533,10 +628,10 @@ fn construct_map_of_unique_values(
     frequency_tables: &[Frequencies<Vec<u8>>],
 ) -> CliResult<AHashMap<String, Vec<String>>> {
     let mut unique_values_map: AHashMap<String, Vec<String>> = AHashMap::new();
-
+    let mut unique_values = Vec::with_capacity(freq_csv_fields.len());
     // iterate through fields and gather unique values for each field
     for (i, header_byte_slice) in freq_csv_fields.iter().enumerate() {
-        let mut unique_values = Vec::new();
+        unique_values.clear();
 
         for (val_byte_vec, _count) in frequency_tables[i].most_frequent() {
             let val_string = convert_to_string(val_byte_vec.as_slice())?;
@@ -548,17 +643,16 @@ fn construct_map_of_unique_values(
         // sort the values so enum list so schema can be diff'ed between runs
         unique_values.sort_unstable();
 
-        if log::log_enabled!(log::Level::Debug) {
-            // we do this as this debug is relatively expensive
-            debug!(
-                "enum[{header_string}]: len={}, val={:?}",
-                unique_values.len(),
-                unique_values
-            );
-        }
-        unique_values_map.insert(header_string, unique_values);
+        // if log::log_enabled!(log::Level::Debug) {
+        //     // we do this as this debug is relatively expensive
+        //     debug!(
+        //         "enum[{header_string}]: len={}, val={:?}",
+        //         unique_values.len(),
+        //         unique_values
+        //     );
+        // }
+        unique_values_map.insert(header_string, unique_values.clone());
     }
-
     // dbg!(&unique_values_map);
 
     Ok(unique_values_map)
@@ -645,8 +739,7 @@ fn generate_string_patterns(
         }
     }
 
-    debug!("unique values for eligible pattern columns: {unique_values_map:?}");
-
+    // build regex pattern for each header
     pattern_map.reserve(unique_values_map.len());
     for (header, value_set) in unique_values_map.iter() {
         // Convert Set to Vector
