@@ -46,9 +46,10 @@ https://github.com/jqnatividad/belt/tree/main/dateparser#accepted-date-formats.
 Computing statistics on a large file can be made much faster if you create an index for it
 first with 'qsv index' to enable multithreading.
 
-This command caches the results in <FILESTEM>.stats.csv (e.g., qsv stats nyc311.csv
-will create nyc311.stats.csv), and the arguments used to generate the stats are saved in
-<FILESTEM>.stats.csv.json.
+This command caches the results in <FILESTEM>.stats.csv and <FILESTEM>.stats.csv.bin
+(e.g., qsv stats nyc311.csv will create nyc311.stats.csv and nyc311.stats.csv.bin).
+The .bin file is the binary format of the computed stats. The arguments used to generate the
+cached stats are saved in <FILESTEM>.stats.csv.json.
 
 If stats have already been computed for the input file with similar arguments and the file
 hasn't changed, the stats will be loaded from the cache instead of recomputing it.
@@ -116,6 +117,10 @@ stats options:
                               Note that a file handle is opened for each job.
                               When not set, the number of jobs is set to the
                               number of CPUs detected.
+    --stats-binout <file>     Write the stats to <file> in binary format.
+                              This is used by other qsv commands (currently `schema` and
+                              `tojsonl`) to load the stats into memory without having to
+                              process/parse the CSV again.
 
 Common options:
     -h, --help             Display this message
@@ -175,7 +180,7 @@ use crate::{
 };
 
 #[allow(clippy::unsafe_derive_deserialize)]
-#[derive(Clone, Deserialize)]
+#[derive(Clone, Deserialize, Debug)]
 pub struct Args {
     pub arg_input:            Option<String>,
     pub flag_select:          SelectColumns,
@@ -197,6 +202,7 @@ pub struct Args {
     pub flag_no_headers:      bool,
     pub flag_delimiter:       Option<Delimiter>,
     pub flag_no_memcheck:     bool,
+    pub flag_stats_binout:    Option<String>,
 }
 
 // this struct is used to serialize/deserialize the stats to
@@ -312,6 +318,9 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         fconfig.path = Some(tempfile_path);
     }
 
+    // create stats_binary_encoded_vec to store the stats in binary format
+    let mut stats_binary_encoded_vec: Vec<u8> = Vec::with_capacity(100_000_000);
+
     let mut compute_stats = true;
 
     if let Some(path) = fconfig.path.clone() {
@@ -336,8 +345,21 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                         String::new()
                     }
                 };
+
+            // deserialize the existing stats args json
             let existing_stats_args_json: StatsArgs =
-                serde_json::from_str(&existing_stats_args_json_str)?;
+                match serde_json::from_str(&existing_stats_args_json_str) {
+                    Ok(stat_args) => stat_args,
+                    Err(e) => {
+                        log::warn!(
+                            "Could not serialize {path_file_stem}.stats.csv.json: {e:?}, \
+                             regenerating..."
+                        );
+                        fs::remove_file(&stats_file)?;
+                        fs::remove_file(&stats_args_json_file)?;
+                        StatsArgs::default()
+                    }
+                };
 
             // check if the cached stats are current, use the same args or if the --everything flag
             // was set & all the other non-stats args are equal. If so, we don't need to recompute
@@ -402,6 +424,10 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                     }
                 }
             }?;
+
+            // store binary version of the stats in memory, so we can write it to disk later
+            stats_binary_encoded_vec = bincode::serialize(&stats).unwrap();
+
             let stats = args.stats_to_records(stats);
 
             wtr.write_record(&args.stat_headers())?;
@@ -460,9 +486,20 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         // save the stats args to "<FILESTEM>.stats.csv.json"
         stats_pathbuf.set_extension("csv.json");
         std::fs::write(
-            stats_pathbuf,
+            stats_pathbuf.clone(),
             serde_json::to_string_pretty(&current_stats_args).unwrap(),
         )?;
+
+        // save the binary encoded stats to "<FILESTEM>.stats.csv.bin"
+        stats_pathbuf.set_extension("bin");
+        if stats_binary_encoded_vec.len() > 0 {
+            fs::write(stats_pathbuf.clone(), stats_binary_encoded_vec)?;
+
+            // if the user specified --stats-binout, copy the binary stats to that file as well
+            if let Some(stats_binout) = args.flag_stats_binout {
+                fs::copy(stats_pathbuf, stats_binout)?;
+            }
+        }
     }
 
     if stdout_output_flag {
@@ -482,7 +519,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
 }
 
 impl Args {
-    pub fn sequential_stats(&self, whitelist: &str) -> CliResult<(csv::ByteRecord, Vec<Stats>)> {
+    fn sequential_stats(&self, whitelist: &str) -> CliResult<(csv::ByteRecord, Vec<Stats>)> {
         let mut rdr = self.rconfig().reader()?;
         let (headers, sel) = self.sel_headers(&mut rdr)?;
 
@@ -497,7 +534,7 @@ impl Args {
         Ok((headers, stats))
     }
 
-    pub fn parallel_stats(
+    fn parallel_stats(
         &self,
         whitelist: &str,
         idx_count: u64,
@@ -547,7 +584,7 @@ impl Args {
         Ok((headers, merge_all(recv.iter()).unwrap_or_default()))
     }
 
-    pub fn stats_to_records(&self, stats: Vec<Stats>) -> Vec<csv::StringRecord> {
+    fn stats_to_records(&self, stats: Vec<Stats>) -> Vec<csv::StringRecord> {
         let round_places = self.flag_round;
         let mut records = Vec::with_capacity(stats.len());
         records.extend(repeat(csv::StringRecord::new()).take(stats.len()));
@@ -598,7 +635,7 @@ impl Args {
         Ok((sel.select(&headers).collect(), sel))
     }
 
-    pub fn rconfig(&self) -> Config {
+    fn rconfig(&self) -> Config {
         Config::new(&self.arg_input)
             .delimiter(self.flag_delimiter)
             .no_headers(self.flag_no_headers)
@@ -768,7 +805,7 @@ fn init_date_inference(
     Ok(())
 }
 
-#[derive(Clone, Debug, Eq, PartialEq)]
+#[derive(Clone, Debug, Eq, PartialEq, Default, Serialize, Deserialize)]
 struct WhichStats {
     include_nulls: bool,
     sum:           bool,
@@ -789,7 +826,7 @@ impl Commute for WhichStats {
     }
 }
 
-#[derive(Clone)]
+#[derive(Clone, Serialize, Deserialize, Debug, PartialEq)]
 pub struct Stats {
     typ:       FieldType,
     sum:       Option<TypedSum>,
@@ -1264,8 +1301,8 @@ impl Commute for Stats {
 }
 
 #[allow(clippy::enum_variant_names)]
-#[derive(Clone, Copy, PartialEq, Default)]
-pub enum FieldType {
+#[derive(Clone, Copy, PartialEq, Default, Serialize, Deserialize)]
+enum FieldType {
     // The default - TNull, is the most specific type.
     // Type inference proceeds by assuming the most specific type and then
     // relaxing the type as counter-examples are found.
@@ -1389,7 +1426,7 @@ impl fmt::Debug for FieldType {
 
 /// `TypedSum` keeps a rolling sum of the data seen.
 /// It sums integers until it sees a float, at which point it sums floats.
-#[derive(Clone, Default)]
+#[derive(Clone, Default, Serialize, Deserialize, Debug, PartialEq)]
 struct TypedSum {
     integer: i64,
     float:   Option<f64>,
@@ -1467,7 +1504,7 @@ impl Commute for TypedSum {
 
 /// `TypedMinMax` keeps track of minimum/maximum/range values for each possible type
 /// where min/max/range makes sense.
-#[derive(Clone, Default)]
+#[derive(Clone, Default, Serialize, Deserialize, Debug, PartialEq)]
 struct TypedMinMax {
     strings:  MinMax<Vec<u8>>,
     str_len:  MinMax<usize>,
@@ -1485,35 +1522,24 @@ impl TypedMinMax {
             return;
         }
         self.strings.add(sample.to_vec());
-        // safety: we can use unwrap_unchecked below since we know the data type of the sample
-        unsafe {
-            match typ {
-                TString | TNull => {}
-                TFloat => {
-                    let n = from_utf8(sample)
-                        .unwrap_unchecked()
-                        .parse::<f64>()
-                        .unwrap_unchecked();
+        // safety: we can use unwrap below since we know the data type of the sample
+        match typ {
+            TString | TNull => {}
+            TFloat => {
+                let n = from_utf8(sample).unwrap().parse::<f64>().unwrap();
 
-                    self.floats.add(n);
-                    self.integers.add(n as i64);
-                }
-                TInteger => {
-                    let n = from_utf8(sample)
-                        .unwrap_unchecked()
-                        .parse::<i64>()
-                        .unwrap_unchecked();
-                    self.integers.add(n);
-                    #[allow(clippy::cast_precision_loss)]
-                    self.floats.add(n as f64);
-                }
-                TDate | TDateTime => {
-                    let n = from_utf8(sample)
-                        .unwrap_unchecked()
-                        .parse::<i64>()
-                        .unwrap_unchecked();
-                    self.dates.add(n);
-                }
+                self.floats.add(n);
+                self.integers.add(n as i64);
+            }
+            TInteger => {
+                let n = from_utf8(sample).unwrap().parse::<i64>().unwrap();
+                self.integers.add(n);
+                #[allow(clippy::cast_precision_loss)]
+                self.floats.add(n as f64);
+            }
+            TDate | TDateTime => {
+                let n = from_utf8(sample).unwrap().parse::<i64>().unwrap();
+                self.dates.add(n);
             }
         }
     }
