@@ -24,6 +24,10 @@ Load same files into a new/existing postgres database whose connection string is
 
   $ qsv to postgres 'env=DATABASE_URL' file1.csv file2.csv
 
+Load files inside a directory to a local database 'test' with user `testuser`, password `pass`.
+
+  $ qsv to postgres 'postgres://testuser:pass@localhost/test' dir1 
+
 Drop tables if they exist before loading.
 
   $ qsv to postgres 'postgres://testuser:pass@localhost/test' --drop file1.csv file2.csv
@@ -53,6 +57,10 @@ Load `file1.csv` and `file2.csv' files to sqlite database `test.db`
 
   $ qsv to sqlite test.db file1.csv file2.csv
 
+Load all files in dir1 to sqlite database `test.db`
+
+  $ qsv to sqlite test.db dir
+
 Drop tables if they exist before loading.
 
   $ qsv to sqlite test.db --drop file1.csv file2.csv
@@ -108,10 +116,15 @@ Add more stats to datapackage.
 
   $ qsv to datapackage datapackage.json --stats file1.csv file2.csv
 
+Generate a `datapackage.json` file from all the files in dir1
+
+  $ qsv to datapackage datapackage.json dir1
+
 For all other conversions you can output the datapackage created by specifying `--print-package`.
 
   $ qsv to xlsx datapackage.xlsx --stats --print-package file1.csv file2.csv
 
+For more examples, see https://github.com/jqnatividad/qsv/blob/master/tests/test_to.rs.
 
 Usage:
     qsv to postgres [options] <postgres> [<input>...]
@@ -121,7 +134,7 @@ Usage:
     qsv to datapackage [options] <datapackage> [<input>...]
     qsv to --help
 
-options:
+To options:
     -k --print-package     Print statistics as datapackage, by default will print field summary.
     -u --dump              Create database dump file for use with `psql` or `sqlite3` command line tools (postgres/sqlite only).
     -a --stats             Produce extra statistics about the data beyond just type guessing.
@@ -217,8 +230,8 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
 
     if args.cmd_postgres {
         debug!("converting to postgres");
-        process_input(
-            &mut arg_input,
+        arg_input = process_input(
+            arg_input,
             &tmpdir,
             "No data on stdin. Need to add connection string as first argument then the input CSVs",
         )?;
@@ -235,8 +248,8 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         debug!("conversion to postgres complete");
     } else if args.cmd_sqlite {
         debug!("converting to sqlite");
-        process_input(
-            &mut arg_input,
+        arg_input = process_input(
+            arg_input,
             &tmpdir,
             "No data on stdin. Need to add the name of a sqlite db as first argument then the \
              input CSVs",
@@ -254,7 +267,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         debug!("conversion to sqlite complete");
     } else if args.cmd_parquet {
         debug!("converting to parquet");
-        if args.arg_input.is_empty() {
+        if arg_input.is_empty() {
             return fail_clierror!(
                 "Need to add the directory of the parquet files as first argument then the input \
                  CSVs"
@@ -262,14 +275,14 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         }
         output = csvs_to_parquet_with_options(
             args.arg_parquet.expect("checked above"),
-            args.arg_input,
+            arg_input,
             options,
         )?;
         debug!("conversion to parquet complete");
     } else if args.cmd_xlsx {
         debug!("converting to xlsx");
-        process_input(
-            &mut arg_input,
+        arg_input = process_input(
+            arg_input,
             &tmpdir,
             "No data on stdin. Need to add the name of an xlsx file as first argument then the \
              input CSVs",
@@ -280,8 +293,8 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         debug!("conversion to xlsx complete");
     } else if args.cmd_datapackage {
         debug!("creating datapackage");
-        process_input(
-            &mut arg_input,
+        arg_input = process_input(
+            arg_input,
             &tmpdir,
             "No data on stdin. Need to add the name of a datapackage file as first argument then \
              the input CSVs",
@@ -369,11 +382,22 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
     Ok(())
 }
 
+/// Process the input files and return a vector of paths to the input files
+///
+/// If the input is empty, try to copy stdin to a file named stdin in the passed temp directory
+/// If the input is empty and stdin is empty, return an error
+/// If it's not empty, check the input files if they exist
+///
+/// If the input is a directory, add all the files in the directory to the input
+/// If the input is a file, add the file to the input
+/// If the input are snappy compressed files, uncompress them before adding them to the input
 fn process_input(
-    arg_input: &mut Vec<PathBuf>,
+    arg_input: Vec<PathBuf>,
     tmpdir: &tempfile::TempDir,
     empty_stdin_errmsg: &str,
-) -> Result<(), CliError> {
+) -> Result<Vec<PathBuf>, CliError> {
+    let mut processed_input = Vec::with_capacity(arg_input.len());
+
     if arg_input.is_empty() {
         // copy stdin to a file named stdin in a temp directory
         let tmp_filename = tmpdir.path().join("stdin");
@@ -383,7 +407,46 @@ fn process_input(
             return fail_clierror!("{empty_stdin_errmsg}");
         }
         tmp_file.flush()?;
-        arg_input.push(tmp_filename);
+        processed_input.push(tmp_filename);
+    } else {
+        let mut work_input = Vec::with_capacity(arg_input.len());
+
+        // is the input a directory?
+        if arg_input.len() == 1 && arg_input[0].is_dir() {
+            // if so, add all the files in the directory to the input
+            let dir = std::fs::read_dir(arg_input[0].clone())?;
+            for entry in dir {
+                let entry = entry?;
+                let path = entry.path();
+                if path.is_file() {
+                    work_input.push(path);
+                }
+            }
+        } else {
+            work_input = arg_input;
+        }
+
+        // check the input files
+        for path in work_input {
+            // does the input file exist?
+            if !path.exists() {
+                return fail_clierror!("Input file '{}' does not exist", path.display());
+            }
+            // is the input file snappy compressed?
+            if path.extension().unwrap_or_default() == "sz" {
+                // if so, decompress the file
+                let mut snappy_file = std::fs::File::open(path.clone())?;
+                let mut snappy_reader = snap::read::FrameDecoder::new(&mut snappy_file);
+                let file_stem = path.file_stem().unwrap_or_default();
+                let decompressed_filepath = tmpdir.path().join(file_stem);
+                let mut decompressed_file = std::fs::File::create(decompressed_filepath.clone())?;
+                std::io::copy(&mut snappy_reader, &mut decompressed_file)?;
+                decompressed_file.flush()?;
+                processed_input.push(decompressed_filepath);
+            } else {
+                processed_input.push(path.clone());
+            }
+        }
     }
-    Ok(())
+    Ok(processed_input)
 }
