@@ -97,7 +97,7 @@ fn main() -> QsvExitCode {
     cat         Concatenate by row or column
     count       Count records
     dedup       Remove redundant rows
-    diff        Create the difference between two CSVs
+    diff        Find the difference between two CSVs
     enum        Add a new column enumerating CSV lines
     excel       Exports an Excel sheet to a CSV
     exclude     Excludes the records in one CSV from another
@@ -163,6 +163,7 @@ fn main() -> QsvExitCode {
     searchset   Search CSV data with a regex set
     select      Select, re-order, duplicate or drop columns
     slice       Slice records from CSV
+    snappy      Compress/decompress data using the Snappy algorithm
     sniff       Quickly sniff CSV metadata
     sort        Sort CSV data in alphabetical, numerical, reverse or random order
     sortcheck   Check if a CSV is sorted
@@ -318,6 +319,7 @@ enum Command {
     SearchSet,
     Select,
     Slice,
+    Snappy,
     Sniff,
     Sort,
     SortCheck,
@@ -398,6 +400,7 @@ impl Command {
             Command::SearchSet => cmd::searchset::run(argv),
             Command::Select => cmd::select::run(argv),
             Command::Slice => cmd::slice::run(argv),
+            Command::Snappy => cmd::snappy::run(argv),
             Command::Sniff => {
                 let rt = tokio::runtime::Runtime::new().unwrap();
                 rt.block_on(cmd::sniff::run(argv))
