@@ -55,6 +55,7 @@ macro_rules! command_list {
         "
     applydp     Apply series of transformations to a column
     count       Count records
+    diff        Find the difference between two CSVs
     dedup       Remove redundant rows
     excel       Exports an Excel sheet to a CSV
     exclude     Excludes the records in one CSV from another
@@ -74,6 +75,7 @@ macro_rules! command_list {
     searchset   Search CSV data with a regex set
     select      Select, re-order, duplicate or drop columns
     slice       Slice records from CSV
+    snappy      Compress/decompress data using the Snappy algorithm
     sniff       Quickly sniff CSV metadata
     sort        Sort CSV data in alphabetical, numerical, reverse or random order
     sortcheck   Check if a CSV is sorted
@@ -204,6 +206,7 @@ enum Command {
     ApplyDP,
     Count,
     Dedup,
+    Diff,
     Excel,
     Exclude,
     ExtDedup,
@@ -223,6 +226,7 @@ enum Command {
     SearchSet,
     Select,
     Slice,
+    Snappy,
     Sniff,
     Sort,
     SortCheck,
@@ -246,6 +250,7 @@ impl Command {
             Command::ApplyDP => cmd::applydp::run(argv),
             Command::Count => cmd::count::run(argv),
             Command::Dedup => cmd::dedup::run(argv),
+            Command::Diff => cmd::diff::run(argv),
             Command::Excel => cmd::excel::run(argv),
             Command::Exclude => cmd::exclude::run(argv),
             Command::ExtDedup => cmd::extdedup::run(argv),
@@ -269,6 +274,7 @@ impl Command {
             Command::SearchSet => cmd::searchset::run(argv),
             Command::Select => cmd::select::run(argv),
             Command::Slice => cmd::slice::run(argv),
+            Command::Snappy => cmd::snappy::run(argv),
             Command::Sniff => {
                 let rt = tokio::runtime::Runtime::new().unwrap();
                 rt.block_on(cmd::sniff::run(argv))
